BlockEvent

Enum BlockEvent 

pub enum BlockEvent<'a> {
    Midi {
        offset: u32,
        bytes: [u8; 3],
        len: u8,
    },
    MidiLong {
        offset: u32,
        bytes: &'a [u8],
    },
    ParamSet {
        offset: u32,
        param: u32,
        value: f64,
    },
    NoteOn {
        offset: u32,
        channel: u8,
        key: u8,
        velocity: f32,
    },
    NoteOff {
        offset: u32,
        channel: u8,
        key: u8,
        velocity: f32,
    },
}
An event delivered to or emitted by a processor within a block, timestamped by a sample offset into the block.

Variants



Midi

A short MIDI message of up to three bytes.

Fields

offset: u32

Sample offset into the block.

bytes: [u8; 3]

Message bytes (only the first len are valid).

len: u8

Number of valid bytes in bytes.



MidiLong

A long MIDI message (for example sysex) borrowing its bytes.

Fields

offset: u32

Sample offset into the block.

bytes: &'a [u8]

Borrowed message bytes.



ParamSet

A parameter-set event.

Fields

offset: u32

Sample offset into the block.

param: u32

Parameter index.

value: f64

New parameter value.



NoteOn

A note-on event.

Fields

offset: u32

Sample offset into the block.

channel: u8

MIDI channel.

key: u8

MIDI key number.

velocity: f32

Normalized velocity.



NoteOff

A note-off event.

Fields

offset: u32

Sample offset into the block.

channel: u8

MIDI channel.

key: u8

MIDI key number.

velocity: f32

Normalized release velocity.